import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Component, createRef } from 'react';
import PropTypes from 'prop-types';
import ResizeObserver from 'resize-observer-polyfill';
import shallowEqual from 'shallowequal';
import { BREAKPOINTS } from './breakpoints';
import { getWidth, matchQueries } from './helpers';
import { jsx as _jsx } from "react/jsx-runtime";
var LayoutMediaQueryFactory = function LayoutMediaQueryFactory(BREAKPOINTS) {
  var _class;
  return _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(_class, _Component);
    function _class() {
      var _this;
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.containerRef = /*#__PURE__*/createRef();
      _this.state = {
        params: _this.props.initialMediaQueries
      };
      _this.containerResizeObserver = null;
      _this.matchQueries = matchQueries(BREAKPOINTS);
      _this.handleWindowResize = function (e) {
        var width = e.target.outerWidth;
        var params = _this.state.params;
        var result = _this.matchQueries(width);
        if (!shallowEqual(result, params)) _this.setState({
          params: result
        });
      };
      _this.handleContainerResize = function (entries) {
        var target = entries[0].target;
        var width = getWidth(target);
        var params = _this.state.params;
        var result = _this.matchQueries(width);
        if (!shallowEqual(result, params)) _this.setState({
          params: result
        });
      };
      return _this;
    }
    var _proto = _class.prototype;
    _proto.componentDidMount = function componentDidMount() {
      var viewport = this.props.viewport; // eslint-disable-line react/prop-types
      var container = this.containerRef.current;
      var initialWidth = 0;
      if (viewport) {
        window.addEventListener('resize', this.handleWindowResize);
        initialWidth = window.outerWidth;
      } else {
        this.containerResizeObserver = new ResizeObserver(this.handleContainerResize);
        this.containerResizeObserver.observe(container);
        initialWidth = getWidth(container);
      }
      var result = this.matchQueries(initialWidth);
      this.setState({
        params: result
      });
    };
    _proto.componentWillUnmount = function componentWillUnmount() {
      this.containerResizeObserver && this.containerResizeObserver.disconnect();
      this.containerResizeObserver = null;
      window.removeEventListener('resize', this.handleResize);
    };
    _proto.shouldComponentUpdate = function shouldComponentUpdate(_, nextState) {
      return !shallowEqual(this.state.params, nextState.params);
    };
    _proto.render = function render() {
      return /*#__PURE__*/_jsx("div", {
        className: "sui-Layout-MediaQuery",
        ref: this.containerRef,
        children: this.props.children(this.state.params)
      });
    };
    return _class;
  }(Component), _class.defaultProps = {
    initialMediaQueries: {}
  }, _class;
};
var LayoutMediaQuery = LayoutMediaQueryFactory(BREAKPOINTS);
LayoutMediaQuery.displayName = 'LayoutMediaQuery';
LayoutMediaQuery.propTypes = {
  /** Wether to listen to the viewport resize or not (it listens to the container resize by default) */
  viewport: PropTypes.bool
};
export default LayoutMediaQuery;
export { LayoutMediaQueryFactory };